@@ -18,12 +18,19 @@ module.exports = {
   moduleDirectories: [
     'node_modules',
   ],
+  moduleNameMapper: {
+    // mapping for absolute imports (see tsconfig.json)
+    '^@/(.*)$': '<rootDir>/src/$1',
+  },
   collectCoverageFrom: [
     ...base.collectCoverageFrom,
 
     '!src/localRun/**',
+    '!src/utils/**',
+    '!src/server.ts',
   ],
   testEnvironment: 'node',
+  setupFilesAfterEnv: ['./jest.setup.js'],
   coverageThreshold: {
     global: {
       statements: 81,
