@@ -20,11 +20,16 @@ import { api } from '@eclipse-che/common';
 import * as k8s from '@kubernetes/client-node';
 import { V1Status } from '@kubernetes/client-node';
 import http, { IncomingHttpHeaders } from 'http';
-import { MessageListener } from '../../services/types/Observer';
-import { IDevWorkspaceApi } from '../types';
-import { createError } from './helpers/createError';
-import { CustomObjectAPI, prepareCustomObjectAPI } from './helpers/prepareCustomObjectAPI';
-import { prepareCustomObjectWatch } from './helpers/prepareCustomObjectWatch';
+
+import { createError } from '@/devworkspaceClient/services/helpers/createError';
+import {
+  CustomObjectAPI,
+  prepareCustomObjectAPI,
+} from '@/devworkspaceClient/services/helpers/prepareCustomObjectAPI';
+import { prepareCustomObjectWatch } from '@/devworkspaceClient/services/helpers/prepareCustomObjectWatch';
+import { IDevWorkspaceApi } from '@/devworkspaceClient/types';
+import { MessageListener } from '@/services/types/Observer';
+import { logger } from '@/utils/logger';
 
 const DEV_WORKSPACE_API_ERROR_LABEL = 'CUSTOM_OBJECTS_API_ERROR';
 
@@ -189,7 +194,7 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
         }
       },
       (error: unknown) => {
-        console.error(`[ERROR] Stopped watching ${path}. Reason:`, error);
+        logger.warn(error, `Stopped watching ${path}.`);
       },
     );
 
