@@ -34,7 +34,7 @@ export interface INamespacedPodParams extends INamespacedParams {
 }
 
 export interface ISchemaParams {
-  [key: string]: any;
+  [key: string]: unknown;
 }
 
 export interface ITemplateBodyParams {
@@ -63,3 +63,8 @@ export interface PersonalAccessTokenNamespacedParams extends INamespacedParams {
   namespace: string;
   tokenName: string;
 }
+
+export interface ShhKeyNamespacedParams extends INamespacedParams {
+  namespace: string;
+  name: string;
+}
