@@ -12,8 +12,9 @@
 
 import { FastifyInstance } from 'fastify';
 import * as mockNodeFetch from 'node-fetch';
-import { baseApiPath } from '../../../constants/config';
-import { setup, teardown } from '../../../helpers/tests/appBuilder';
+
+import { baseApiPath } from '@/constants/config';
+import { setup, teardown } from '@/utils/appBuilder';
 
 const { Response } = jest.requireActual<typeof mockNodeFetch>('node-fetch');
 
