@@ -11,16 +11,23 @@
  */
 
 import { FastifyInstance } from 'fastify';
-import { baseApiPath } from '../../constants/config';
-import { getSchema } from '../../services/helpers';
-import { getDevWorkspaceClient } from './helpers/getDevWorkspaceClient';
-import { getServiceAccountToken } from './helpers/getServiceAccountToken';
+
+import { baseApiPath } from '@/constants/config';
+import { getDevWorkspaceClient } from '@/routes/api/helpers/getDevWorkspaceClient';
+import { getServiceAccountToken } from '@/routes/api/helpers/getServiceAccountToken';
+import { getSchema } from '@/services/helpers';
 
 const tags = ['Getting Started Samples'];
 
-export function registerGettingStartedSamplesRoutes(instance: FastifyInstance) {
+export function registerGettingStartedSamplesRoutes(
+  isLocalRun: boolean,
+  instance: FastifyInstance,
+) {
   instance.register(async server => {
     server.get(`${baseApiPath}/getting-started-sample`, getSchema({ tags }), async () => {
+      if (isLocalRun) {
+        return [];
+      }
       const token = getServiceAccountToken();
       const { gettingStartedSampleApi } = getDevWorkspaceClient(token);
       return gettingStartedSampleApi.list();
