@@ -15,10 +15,12 @@ import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
 import { Store } from 'redux';
+
+import { MIN_STEP_DURATION_MS } from '@/components/WorkspaceProgress/const';
+import getComponentRenderer from '@/services/__mocks__/getComponentRenderer';
+import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+
 import CreateWorkspace from '..';
-import getComponentRenderer from '../../../../../services/__mocks__/getComponentRenderer';
-import { FakeStoreBuilder } from '../../../../../store/__mocks__/storeBuilder';
-import { MIN_STEP_DURATION_MS } from '../../../const';
 
 const { renderComponent } = getComponentRenderer(getComponent);
 
