@@ -16,19 +16,24 @@ import isEqual from 'lodash/isEqual';
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
 import { generatePath } from 'react-router-dom';
-import { ROUTE } from '../../../../Routes/routes';
+
+import {
+  ProgressStep,
+  ProgressStepProps,
+  ProgressStepState,
+} from '@/components/WorkspaceProgress/ProgressStep';
+import { ProgressStepTitle } from '@/components/WorkspaceProgress/StepTitle';
+import { ROUTE } from '@/Routes/routes';
 import {
   buildFactoryParams,
   FactoryParams,
   PoliciesCreate,
-} from '../../../../services/helpers/factoryFlow/buildFactoryParams';
-import { AlertItem } from '../../../../services/helpers/types';
-import { AppState } from '../../../../store';
-import { selectAllWorkspacesLimit } from '../../../../store/ClusterConfig/selectors';
-import { selectInfrastructureNamespaces } from '../../../../store/InfrastructureNamespaces/selectors';
-import { selectAllWorkspaces } from '../../../../store/Workspaces/selectors';
-import { ProgressStep, ProgressStepProps, ProgressStepState } from '../../ProgressStep';
-import { ProgressStepTitle } from '../../StepTitle';
+} from '@/services/helpers/factoryFlow/buildFactoryParams';
+import { AlertItem } from '@/services/helpers/types';
+import { AppState } from '@/store';
+import { selectAllWorkspacesLimit } from '@/store/ClusterConfig/selectors';
+import { selectInfrastructureNamespaces } from '@/store/InfrastructureNamespaces/selectors';
+import { selectAllWorkspaces } from '@/store/Workspaces/selectors';
 
 export type Props = MappedProps &
   ProgressStepProps & {
