@@ -15,13 +15,17 @@ import { createHashHistory, History } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
 import { Router } from 'react-router';
-import UserPreferences from '..';
-import getComponentRenderer, { screen } from '../../../services/__mocks__/getComponentRenderer';
-import { FakeStoreBuilder } from '../../../store/__mocks__/storeBuilder';
 
-jest.mock('../GitServicesTab');
+import getComponentRenderer, { screen } from '@/services/__mocks__/getComponentRenderer';
+import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+
+import UserPreferences from '..';
+
 jest.mock('../ContainerRegistriesTab');
+jest.mock('../GitConfig');
+jest.mock('../GitServicesTab');
 jest.mock('../PersonalAccessTokens');
+jest.mock('../SshKeys');
 
 const { renderComponent } = getComponentRenderer(getComponent);
 
@@ -85,14 +89,22 @@ describe('UserPreferences', () => {
 
       expect(screen.queryByRole('tabpanel', { name: 'Personal Access Tokens' })).toBeTruthy();
     });
+
+    it('should activate the SSH Keys tab', () => {
+      history.push('/user-preferences?tab=ssh-keys');
+
+      renderComponent();
+
+      expect(screen.queryByRole('tabpanel', { name: 'SSH Keys' })).toBeTruthy();
+    });
   });
 
   describe('Tabs', () => {
     it('should activate the Container Registries tab', () => {
       renderComponent();
 
-      const devfileTab = screen.getByRole('tab', { name: 'Container Registries' });
-      userEvent.click(devfileTab);
+      const tab = screen.getByRole('tab', { name: 'Container Registries' });
+      userEvent.click(tab);
 
       expect(screen.queryByRole('tabpanel', { name: 'Container Registries' })).toBeTruthy();
     });
@@ -100,8 +112,8 @@ describe('UserPreferences', () => {
     it('should activate the Git Services tab', () => {
       renderComponent();
 
-      const devfileTab = screen.getByRole('tab', { name: 'Git Services' });
-      userEvent.click(devfileTab);
+      const tab = screen.getByRole('tab', { name: 'Git Services' });
+      userEvent.click(tab);
 
       expect(screen.queryByRole('tabpanel', { name: 'Git Services' })).toBeTruthy();
     });
@@ -109,10 +121,28 @@ describe('UserPreferences', () => {
     it('should activate the Personal Access Tokens tab', () => {
       renderComponent();
 
-      const devfileTab = screen.getByRole('tab', { name: 'Personal Access Tokens' });
-      userEvent.click(devfileTab);
+      const tab = screen.getByRole('tab', { name: 'Personal Access Tokens' });
+      userEvent.click(tab);
 
       expect(screen.queryByRole('tabpanel', { name: 'Personal Access Tokens' })).toBeTruthy();
     });
+
+    it('should activate the Gitconfig tab', () => {
+      renderComponent();
+
+      const tab = screen.getByRole('tab', { name: 'Gitconfig' });
+      userEvent.click(tab);
+
+      expect(screen.queryByRole('tabpanel', { name: 'Gitconfig' })).toBeTruthy();
+    });
+
+    it('should activate the SSH Keys tab', () => {
+      renderComponent();
+
+      const tab = screen.getByRole('tab', { name: 'SSH Keys' });
+      userEvent.click(tab);
+
+      expect(screen.queryByRole('tabpanel', { name: 'SSH Keys' })).toBeTruthy();
+    });
   });
 });
