@@ -11,12 +11,14 @@
  */
 
 import { Reducer } from 'redux';
+
+import devfileApi from '@/services/devfileApi';
+import { FactoryParams } from '@/services/helpers/factoryFlow/buildFactoryParams';
+import { Workspace } from '@/services/workspace-adapter';
+import { createObject } from '@/store/helpers';
+import * as DevWorkspacesStore from '@/store/Workspaces/devWorkspaces';
+
 import { AppThunk } from '..';
-import { FactoryParams } from '../../services/helpers/factoryFlow/buildFactoryParams';
-import devfileApi from '../../services/devfileApi';
-import { Workspace } from '../../services/workspace-adapter';
-import { createObject } from '../helpers';
-import * as DevWorkspacesStore from './devWorkspaces';
 
 // This state defines the type of data maintained in the Redux store.
 export interface State {
@@ -300,7 +302,7 @@ export const reducer: Reducer<State> = (state: State | undefined, action: KnownA
 
   switch (action.type) {
     case 'REQUEST_WORKSPACES':
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: true,
       });
     case 'RECEIVE_ERROR':
@@ -308,25 +310,25 @@ export const reducer: Reducer<State> = (state: State | undefined, action: KnownA
     case 'ADD_WORKSPACE':
     case 'DELETE_WORKSPACE':
     case 'RECEIVE_WORKSPACES':
-      return createObject(state, {
+      return createObject<State>(state, {
         isLoading: false,
       });
     case 'SET_WORKSPACE_NAME':
-      return createObject(state, {
+      return createObject<State>(state, {
         namespace: action.namespace,
         workspaceName: action.workspaceName,
       });
     case 'CLEAR_WORKSPACE_NAME':
-      return createObject(state, {
+      return createObject<State>(state, {
         namespace: '',
         workspaceName: '',
       });
     case 'SET_WORKSPACE_UID':
-      return createObject(state, {
+      return createObject<State>(state, {
         workspaceUID: action.workspaceUID,
       });
     case 'CLEAR_WORKSPACE_UID':
-      return createObject(state, {
+      return createObject<State>(state, {
         workspaceUID: '',
       });
     default:
